@@ -56,10 +56,10 @@ async def test_init():
 @pytest.mark.asyncio
 async def test_get_cloud_init():
     skip_without_credentials()
-
-    cloud_init = GCPCluster.get_cloud_init()
+    cloud_init = GCPCluster.get_cloud_init(security=True, docker_args="--privileged")
     assert "dask-scheduler" in cloud_init
     assert "# Bootstrap" in cloud_init
+    assert " --privileged " in cloud_init
 
 
 @pytest.mark.asyncio
@@ -67,13 +67,15 @@ async def test_get_cloud_init():
 async def test_create_cluster():
     skip_without_credentials()
 
-    async with GCPCluster(asynchronous=True, env_vars={"FOO": "bar"}) as cluster:
+    async with GCPCluster(
+        asynchronous=True, env_vars={"FOO": "bar"}, security=True
+    ) as cluster:
 
         assert cluster.status == Status.running
 
-        cluster.scale(1)
+        cluster.scale(2)
         await cluster
-        assert len(cluster.workers) == 1
+        assert len(cluster.workers) == 2
 
         async with Client(cluster, asynchronous=True) as client:
 
@@ -120,7 +122,7 @@ async def test_create_rapids_cluster():
         worker_options={"rmm_pool_size": "15GB"},
         asynchronous=True,
         auto_shutdown=True,
-        boostrap=False,
+        bootstrap=False,
     ) as cluster:
 
         assert cluster.status == Status.running
@@ -150,7 +152,8 @@ async def test_create_rapids_cluster():
 def test_create_rapids_cluster_sync():
     skip_without_credentials()
     cluster = GCPCluster(
-        source_image="projects/nv-ai-infra/global/images/ngc-docker-11-20200916",
+        source_image="projects/nv-ai-infra/global/images/packer-1607527229",
+        network="dask-gcp-network-test",
         zone="us-east1-c",
         machine_type="n1-standard-1",
         filesystem_size=50,
@@ -160,7 +163,7 @@ def test_create_rapids_cluster_sync():
         worker_class="dask_cuda.CUDAWorker",
         worker_options={"rmm_pool_size": "15GB"},
         asynchronous=False,
-        boostrap=False,
+        bootstrap=False,
     )
 
     cluster.scale(1)
@@ -178,5 +181,4 @@ def test_create_rapids_cluster_sync():
     for w, res in results.items():
         assert "total" in res["gpu"][0]["fb_memory_usage"].keys()
         print(res)
-
     cluster.close()
