@@ -5,7 +5,6 @@ def test_imports():
     from dask_cloudprovider.aws import EC2Cluster  # noqa
     from dask_cloudprovider.aws import ECSCluster  # noqa
     from dask_cloudprovider.aws import FargateCluster  # noqa
-    from dask_cloudprovider.azureml import AzureMLCluster  # noqa
     from dask_cloudprovider.azure import AzureVMCluster  # noqa
     from dask_cloudprovider.gcp import GCPCluster  # noqa
     from dask_cloudprovider.digitalocean import DropletCluster  # noqa
@@ -18,8 +17,6 @@ def test_import_exceptions():
         from dask_cloudprovider import ECSCluster  # noqa
     with pytest.raises(ImportError):
         from dask_cloudprovider import FargateCluster  # noqa
-    with pytest.raises(ImportError):
-        from dask_cloudprovider import AzureMLCluster  # noqa
     with pytest.raises(ImportError):
         from dask_cloudprovider import AzureVMCluster  # noqa
     with pytest.raises(ImportError):
